pub enum Match {
Exact,
Contains,
}Expand description
Indicates whether the match on the query term should be exact or contains. If we want to match all queries that contained the word apple, we will use the contains match instead.
Variants