pub struct CurationRule {
pub tags: Option<Vec<String>>,
pub query: Option<String>,
pub match: Option<Match>,
pub filter_by: Option<String>,
}Fields
List of tag values to associate with this curation rule.
query: Option<String>Indicates what search queries should be curated
match: Option<Match>Indicates whether the match on the query term should be exact or contains. If we want to match all queries that contained the word apple, we will use the contains match instead.
filter_by: Option<String>Indicates that the curation should apply when the filter_by parameter in a search query exactly matches the string specified here (including backticks, spaces, brackets, etc).
Implementations
Sourceimpl CurationRule
impl CurationRule
pub fn new() -> CurationRule