pub struct SearchHighlight {
pub field: Option<String>,
pub snippet: Option<String>,
pub snippets: Option<Vec<String>>,
pub value: Option<String>,
pub values: Option<Vec<String>>,
pub indices: Option<Vec<i32>>,
pub matched_tokens: Option<Vec<Value>>,
}Fields
field: Option<String>snippet: Option<String>Present only for (non-array) string fields
snippets: Option<Vec<String>>Present only for (array) string[] fields
value: Option<String>Full field value with highlighting, present only for (non-array) string fields
values: Option<Vec<String>>Full field value with highlighting, present only for (array) string[] fields
indices: Option<Vec<i32>>The indices property will be present only for string[] fields and will contain the corresponding indices of the snippets in the search field
matched_tokens: Option<Vec<Value>>Implementations
Sourceimpl SearchHighlight
impl SearchHighlight
pub fn new() -> SearchHighlight