pub struct SearchSynonym {
pub root: Option<String>,
pub synonyms: Vec<String>,
pub locale: Option<String>,
pub symbols_to_index: Option<Vec<String>>,
pub id: String,
}Fields
root: Option<String>For 1-way synonyms, indicates the root word that words in the synonyms parameter map to.
synonyms: Vec<String>Array of words that should be considered as synonyms.
locale: Option<String>Locale for the synonym, leave blank to use the standard tokenizer.
symbols_to_index: Option<Vec<String>>By default, special characters are dropped from synonyms. Use this attribute to specify which special characters should be indexed as is.
id: StringImplementations
Sourceimpl SearchSynonym
impl SearchSynonym